@@ -4,7 +4,7 @@
 # Author: Haejoong Lee <haejoong@ldc.upenn.edu>
 #         Steven Bird <stevenbird1@gmail.com>
 #         Jacob Perkins <japerk@gmail.com>
-# URL: <http://nltk.org/>
+# URL: <https://www.nltk.org/>
 # For license information, see LICENSE.TXT
 
 # [xx] this docstring is out-of-date:
@@ -20,7 +20,7 @@ This corpus contains selected portion of the TIMIT corpus.
    are spoken by all speakers.)
  - total 160 recording of sentences (10 recordings per speaker)
  - audio format: NIST Sphere, single channel, 16kHz sampling,
-  16 bit sample, PCM encoding
+   16 bit sample, PCM encoding
 
 
 Module contents
@@ -108,7 +108,7 @@ The 4 functions are as follows.
  - audiodata(item, start=0, end=None)
 
    Given an item, returns a chunk of audio samples formatted into a string.
-   When the fuction is called, if start and end are omitted, the entire
+   When the function is called, if start and end are omitted, the entire
    samples of the recording will be returned.  If only end is omitted,
    samples from the start offset to the end of the recording will be returned.
 
@@ -169,7 +169,7 @@ class TimitCorpusReader(CorpusReader):
 
         self._speakerinfo = None
         self._root = root
-        self.speakers = sorted(set(u.split("/")[0] for u in self._utterances))
+        self.speakers = sorted({u.split("/")[0] for u in self._utterances})
 
     def fileids(self, filetype=None):
         """
@@ -184,7 +184,7 @@ class TimitCorpusReader(CorpusReader):
         if filetype is None:
             return CorpusReader.fileids(self)
         elif filetype in ("txt", "wrd", "phn", "wav"):
-            return ["%s.%s" % (u, filetype) for u in self._utterances]
+            return [f"{u}.{filetype}" for u in self._utterances]
         elif filetype == "metadata":
             return ["timitdic.txt", "spkrinfo.txt"]
         else:
@@ -195,9 +195,9 @@ class TimitCorpusReader(CorpusReader):
     ):
         """
         :return: A list of the utterance identifiers for all
-        utterances in this corpus, or for the given speaker, dialect
-        region, gender, sentence type, or sentence number, if
-        specified.
+            utterances in this corpus, or for the given speaker, dialect
+            region, gender, sentence type, or sentence number, if
+            specified.
         """
         if isinstance(dialect, str):
             dialect = [dialect]
@@ -226,7 +226,7 @@ class TimitCorpusReader(CorpusReader):
     def transcription_dict(self):
         """
         :return: A dictionary giving the 'standard' transcription for
-        each word.
+            each word.
         """
         _transcriptions = {}
         with self.open("timitdic.txt") as fp:
@@ -246,12 +246,12 @@ class TimitCorpusReader(CorpusReader):
         return utterance.split("/")[1]
 
     def utterance(self, spkrid, sentid):
-        return "%s/%s" % (spkrid, sentid)
+        return f"{spkrid}/{sentid}"
 
     def spkrutteranceids(self, speaker):
         """
         :return: A list of all utterances associated with a given
-        speaker.
+            speaker.
         """
         return [
             utterance
@@ -273,7 +273,7 @@ class TimitCorpusReader(CorpusReader):
                     if not line.strip() or line[0] == ";":
                         continue
                     rec = line.strip().split(None, 9)
-                    key = "dr%s-%s%s" % (rec[2], rec[1].lower(), rec[0].lower())
+                    key = f"dr{rec[2]}-{rec[1].lower()}{rec[0].lower()}"
                     self._speakerinfo[key] = SpeakerInfo(*rec)
 
         return self._speakerinfo[speaker]
@@ -296,7 +296,13 @@ class TimitCorpusReader(CorpusReader):
             with self.open(fileid) as fp:
                 for line in fp:
                     if line.strip():
-                        results.append((line.split()[2], int(line.split()[0]), int(line.split()[1])))
+                        results.append(
+                            (
+                                line.split()[2],
+                                int(line.split()[0]),
+                                int(line.split()[1]),
+                            )
+                        )
         return results
 
     def words(self, utterances=None):
@@ -314,7 +320,13 @@ class TimitCorpusReader(CorpusReader):
             with self.open(fileid) as fp:
                 for line in fp:
                     if line.strip():
-                        results.append((line.split()[2], int(line.split()[0]), int(line.split()[1])))
+                        results.append(
+                            (
+                                line.split()[2],
+                                int(line.split()[0]),
+                                int(line.split()[1]),
+                            )
+                        )
         return results
 
     def sents(self, utterances=None):
@@ -411,7 +423,7 @@ class TimitCorpusReader(CorpusReader):
             utterances = self._utterances
         if isinstance(utterances, str):
             utterances = [utterances]
-        return ["%s%s" % (u, extension) for u in utterances]
+        return [f"{u}{extension}" for u in utterances]
 
     def play(self, utterance, start=0, end=None):
         """
@@ -430,7 +442,7 @@ class TimitCorpusReader(CorpusReader):
                 dsp.speed(16000)
                 dsp.write(self.audiodata(utterance, start, end))
                 dsp.close()
-            except IOError as e:
+            except OSError as e:
                 print(
                     (
                         "can't acquire the audio device; please "
@@ -446,7 +458,8 @@ class TimitCorpusReader(CorpusReader):
         # Method 2: pygame
         try:
             # FIXME: this won't work under python 3
-            import pygame.mixer, StringIO
+            import pygame.mixer
+            import StringIO
 
             pygame.mixer.init(16000)
             f = StringIO.StringIO(self.wav(utterance, start, end))
@@ -464,7 +477,7 @@ class TimitCorpusReader(CorpusReader):
         )
 
 
-class SpeakerInfo(object):
+class SpeakerInfo:
     def __init__(
         self, id, sex, dr, use, recdate, birthdate, ht, race, edu, comments=None
     ):
@@ -481,7 +494,7 @@ class SpeakerInfo(object):
 
     def __repr__(self):
         attribs = "id sex dr use recdate birthdate ht race edu comments"
-        args = ["%s=%r" % (attr, getattr(self, attr)) for attr in attribs.split()]
+        args = [f"{attr}={getattr(self, attr)!r}" for attr in attribs.split()]
         return "SpeakerInfo(%s)" % (", ".join(args))
 
 
