@@ -1,6 +1,6 @@
 # Natural Language Toolkit: Corpus & Model Downloader
 #
-# Copyright (C) 2001-2021 NLTK Project
+# Copyright (C) 2001-2023 NLTK Project
 # Author: Edward Loper <edloper@gmail.com>
 # URL: <https://www.nltk.org/>
 # For license information, see LICENSE.TXT
@@ -1497,7 +1497,11 @@ class DownloaderGUI:
         for (i, (key, label, callback)) in enumerate(info):
             Label(infoframe, text=label).grid(column=0, row=i, sticky="e")
             entry = Entry(
-                infoframe, font="courier", relief="groove", disabledforeground="black"
+                infoframe,
+                font="courier",
+                relief="groove",
+                disabledforeground="#007aff",
+                foreground="#007aff",
             )
             self._info[key] = (entry, callback)
             entry.bind("<Return>", self._info_save)
@@ -1647,12 +1651,12 @@ class DownloaderGUI:
         if self._table.column_names[col].endswith("Size"):
             if isinstance(val, str):
                 return "  %s" % val
-            elif val < 1024 ** 2:
-                return "  %.1f KB" % (val / 1024.0 ** 1)
-            elif val < 1024 ** 3:
-                return "  %.1f MB" % (val / 1024.0 ** 2)
+            elif val < 1024**2:
+                return "  %.1f KB" % (val / 1024.0**1)
+            elif val < 1024**3:
+                return "  %.1f MB" % (val / 1024.0**2)
             else:
-                return "  %.1f GB" % (val / 1024.0 ** 3)
+                return "  %.1f GB" % (val / 1024.0**3)
 
         if col in (0, ""):
             return str(val)
@@ -2321,11 +2325,9 @@ def build_index(root, base_url):
     # Put it all together
     top_elt = ElementTree.Element("nltk_data")
     top_elt.append(ElementTree.Element("packages"))
-    for package in packages:
-        top_elt[0].append(package)
+    top_elt[0].extend(sorted(packages, key=lambda package: package.get("id")))
     top_elt.append(ElementTree.Element("collections"))
-    for collection in collections:
-        top_elt[1].append(collection)
+    top_elt[1].extend(sorted(collections, key=lambda collection: collection.get("id")))
 
     _indent_xml(top_elt)
     return top_elt
@@ -2392,8 +2394,7 @@ def _find_collections(root):
     Helper for ``build_index()``: Yield a list of ElementTree.Element
     objects, each holding the xml for a single package collection.
     """
-    packages = []
-    for dirname, subdirs, files in os.walk(root):
+    for dirname, _subdirs, files in os.walk(root):
         for filename in files:
             if filename.endswith(".xml"):
                 xmlfile = os.path.join(dirname, filename)
